Field

Trait Field 

pub unsafe trait Field: Subplace + Default {
    const NAME: &'static str;
}
Represents a field of a struct or a tuple of Self::Source.

Required Associated Constants

const NAME: &'static str

The name of the field.

If this represents a field of a tuple or a tuple struct, then this will be the stringified index.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<F, Source, Target> Field for TransmutedField<F, Source, Target>
where F: Field, Source: ?Sized + Pointee<Metadata = Metadata<F::Source>>, Target: ?Sized + Pointee<Metadata = Metadata<F::Target>>,

Source

const NAME: &'static str = F::NAME